#!/bin/bash 

#
# Copyright (c) Members of the EGEE Collaboration. 2004.
# See http://www.eu-egee.org/partners/ for details on the copyright holders.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
#  GLite Data Transfer Scripts
#
#  Authors: Paolo Badino <paolo.badino@cern.ch>
#  Version info: $Id: common.sh,v 1.5 2007/05/31 14:43:41 badino Exp $
#  Release: $Name:  $
#
#

# Check that GLITE_LOCATION is set
if [ "x$GLITE_LOCATION" == "x" ] ; then
    echo "GLITE_LOCATION Environment variable is not set. Please fix your profile";
    exit -1;
fi

# Check that GLITE_LOCATION_VAR is set
if [ "x$GLITE_LOCATION_VAR" == "x" ] ; then
    echo "GLITE_LOCATION_VAR Environment variable is not set. Assume the default";
    GLITE_LOCATION_VAR="$GLITE_LOCATION/var"
    if [ ! -d $GLITE_LOCATION_VAR ] ; then
        echo "$GLITE_LOCATION_VAR does not exist"
        exit -1;
    fi
fi

# Check that GLITE_LOCATION_LOG is set
if [ "x$GLITE_LOCATION_LOG" == "x" ] ; then
    echo "GLITE_LOCATION_LOG Environment variable is not set. Assume the default";
    GLITE_LOCATION_LOG="$GLITE_LOCATION_VAR/log"
    if [ ! -d $GLITE_LOCATION_LOG ] ; then
        echo "$GLITE_LOCATION_LOG does not exist"
        exit -1;
    fi
fi

# Set the default value for the Environemnt File
if [ "x$REPORTS_ENV" == "x" ] ; then
    REPORTS_ENV=$GLITE_LOCATION_VAR/glite-transfer-fts/reports/etc/report-env.sh
fi

# Check that environment script is available
if [ -f "$REPORTS_ENV" ] ; then
    # Source the environment 
    source $REPORTS_ENV
else
    echo "No environment file found in $REPORTS_ENV";
    exit -1;
fi

###############################################################################
# Log finctions
###############################################################################

#
#  log_debug
#
function log_debug {
   if [ "x$DEBUG_ENABLED" != "x" ]; then
       echo "DEBUG: $1"
   fi 
}
#
#  log error and exit
#
function error {
   echo "ERROR: $1"
   exit 1
}

###############################################################################
# Set the Default Values
###############################################################################

# Python
if [ "x$PYTHON" == "x" ] ; then
    PYTHON=/usr/bin/python
fi

# Set the output file is defined
if [ "x$REPORTS_OUT_FILE" == "x" ] ; then
    REPORTS_OUT_FILE=$GLITE_LOCATION_LOG/glite-transfer-fts/publishing/gridview.dat
fi

# FTS Gridview Publishing Scripts Directory
if [ "x$REPORTS_SCRIPTS_DIR" == "x" ] ; then
    REPORTS_SCRIPTS_DIR=$GLITE_LOCATION/share/glite-data-transfer-scripts/publishing/gridview
fi

# Include Oracle lib in LD_LIBRARY_PATH
if [ "x$ORACLE_LOCATION" != "x" ] ; then
    # Check that the folder exists
    if [ -d $ORACLE_LOCATION/client/lib ] ; then 
        export LD_LIBRARY_PATH=$ORACLE_LOCATION/client/lib:$LD_LIBRARY_PATH
    else
        # check with ORACLE_LOCATION/lib
        if [ -d $ORACLE_LOCATION/lib ] ; then
            export LD_LIBRARY_PATH=$ORACLE_LOCATION/lib:$LD_LIBRARY_PATH
        else
            echo "neither $ORACLE_LOCATION/client/lib nor $ORACLE_LOCATION/lib exist";
            exit -1;
        fi
    fi
fi

# Print the configuration information
log_debug "GLITE_LOCATION:      $GLITE_LOCATION";
log_debug "GLITE_LOCATION_VAR:  $GLITE_LOCATION_VAR";
log_debug "GLITE_LOCATION_LOG:  $GLITE_LOCATION_LOG";
log_debug "PYTHON:              $PYTHON";
log_debug "REPORTS_OUT_FILE:    $REPORTS_OUT_FILE";
log_debug "REPORTS_SCRIPTS_DIR: $REPORTS_SCRIPTS_DIR";
log_debug "PYTHONPATH:          $PYTHONPATH";
log_debug "LD_LIBRARY_PATH:     $LD_LIBRARY_PATH";

###############################################################################
# Functions
###############################################################################

#
# check preconditions
#
function check_preconditions {
    if [ "x$REPORTS_OUT_FILE" == "x" ]; then
        error "No Reports Output set"
    fi
}

#
# Validation
#
function validate_environment {

    # Check Preconditions
    check_preconditions

    log_debug "Run Report Validation"

    # Run Report 
    log_debug "$PYTHON $REPORTS_SCRIPTS_DIR/fts-2-gridview.py -u $DB_USER -p $DB_PASSWORD -c \"$DB_CONNECT_STR\" -Z"
    $PYTHON $REPORTS_SCRIPTS_DIR/fts-2-gridview.py -u $DB_USER -p $DB_PASSWORD -c "$DB_CONNECT_STR" -Z
    if [ $? -ne 0 ]; then
        error "Failed to run validation"
    fi

    log_debug "Validation Success"
}

#
# Publish data for gridview
#
function gridview_publishing {

    # Check Preconditions
    check_preconditions

    # Set Report Output Directory
    REPORTS_OUT_DIR=`dirname ${REPORTS_OUT_FILE}`
    if [ ! -d $REPORTS_OUT_DIR ]; then
        log_debug "Making directory $REPORTS_OUT_DIR"
        mkdir -p $REPORTS_OUT_DIR
    fi
    
    log_debug "Executing gridview publishing script"

    # Run Report 
    log_debug "$PYTHON $REPORTS_SCRIPTS_DIR/fts-2-gridview.py -u $DB_USER -p $DB_PASSWORD -c \"$DB_CONNECT_STR\" -o \"$REPORTS_OUT_FILE\""
    $PYTHON $REPORTS_SCRIPTS_DIR/fts-2-gridview.py -u $DB_USER -p $DB_PASSWORD -c "$DB_CONNECT_STR" -o "$REPORTS_OUT_FILE"
    if [ $? -ne 0 ]; then
        error "Failed to execute gridview publishing script" 
    fi

    log_debug "data published for gridview"
}

#
# Publish data for gridview summary
#
function gridview_summary_publishing {

    # Check Preconditions
    check_preconditions

    # Set Report Output Directory
    REPORTS_OUT_DIR=`dirname ${REPORTS_OUT_FILE}`
    if [ ! -d $REPORTS_OUT_DIR ]; then
        log_debug "Making directory $REPORTS_OUT_DIR"
        mkdir -p $REPORTS_OUT_DIR
    fi
    
    log_debug "Executing gridview summary publishing script"

    # Run Report 
    log_debug "$PYTHON $REPORTS_SCRIPTS_DIR/fts-2-gridview.py -u $DB_USER -p $DB_PASSWORD -c \"$DB_CONNECT_STR\" -o \"$REPORTS_OUT_FILE\" -S $SUMMARY_TYPE"
    $PYTHON $REPORTS_SCRIPTS_DIR/fts-2-gridview.py -u $DB_USER -p $DB_PASSWORD -c "$DB_CONNECT_STR" -o "$REPORTS_OUT_FILE" -S $SUMMARY_TYPE
    if [ $? -ne 0 ]; then
        error "Failed to execute gridview summary publishing script" 
    fi

    log_debug "summary published for gridview"
}

